header.main {
    position: fixed;
    top: 0;
    left: 0;
    border-bottom: 1px solid var(--header-border-color);
    background: var(--header-background-color);
    color: var(--header-color);
    width: 100%;
    z-index: 2;
    margin: 0;
    padding: .8rem 0;
    display: flex;
    align-items: center;
    justify-content: space-between;
}
header.main a.logo {
    background: var(--logo-position) var(--logo-url);
    display: block;
    width: 10rem;
    height: 3rem;
    margin: 0 0 0 5%;
}

header.main .title {
    text-align: center;
}
header.main h1,
header.main h2 {
    margin: 0;
    font-size: 1.6rem;
    line-height: 1.56;
}
header.main h1 {
    margin-bottom: .8rem;
    font-size: 2rem;
}
header.main h1 a {
    text-decoration: none;
}
header.main h1 a:hover {
    text-decoration: underline;
}

header.main nav ul {
    list-style-type: none;
}

header.main h2 a {
    padding: .25rem 3rem .2rem .8rem;
    background: var(--header-dropdown-background);
    text-decoration: none;
    border: 1px solid var(--header-border-color);
    font-style: normal;
}
header.main nav[aria-role="main"] {
    display: none;
}
header.main nav[aria-role="main"].opened {
    display: block;
    position: fixed;
    width: 40rem;
    top: 5.7rem;
    left: calc(50% - 17.5rem);
    background: var(--header-background-color);
    border: 1px solid var(--header-border-color);
    overflow: auto;
    max-height: 82vh;
}
header.main nav[aria-role="main"] ul {
    margin: 1.5rem;
    padding: 0;
}
header.main nav[aria-role="main"] ul li.selected::before {
    content: '☞ ';
}
header.main nav[aria-role="main"] ul li:not(.selected)::before {
    content: '     ';
}

header.main nav[aria-role="prev-next"] ul {
    display: flex;
    line-height: 1;
    margin: .5rem 3rem .5rem 1rem;
    padding: 0;
}
header.main nav[aria-role="prev-next"] li {
    margin: .25rem .4rem;
}
header.main nav[aria-role="prev-next"] li a {
    display: inline-block;
    height: 35px;
    width: 35px;
}
header.main nav[aria-role="prev-next"] li a[rel="prev"] {
    background: url("./svg/chevron-left.svg") center center no-repeat;
    background-size: 100%;
}
header.main nav[aria-role="prev-next"] li a[rel="next"] {
    background: url("./svg/chevron-right.svg") center center no-repeat;
    background-size: 100%;
}

/* Make sure the title is not hidden by the fixed header. */
h1.title {
    margin-top: 5rem;
    line-height: 1.25;
    max-width: 60%;
}
.searchnote {
    float: right;
    min-width: 40%;
    margin-top: 10rem;
}
