:root {
    --font-family: 'janon';
    --body-background: #fffff8;
    --body-color: #000;

    --logo-position: no-repeat left center/100%;
    --logo-url: url("./svg/logo_ateliersSP-short_chemin.svg");
    --small-logo-url: url("./svg/sp_logo_acronyme.svg");

    --balloon-color: #B35F1F;
    --balloon-color-font: #fff;
    --balloon-font-size: .9rem;

    --termeenrichi-background-image: url("./svg/plus.svg");
    --termeenrichi-background-image-reversed: url("./svg/plus-reversed.svg");
    --termeenrichi-background-image-expanded: url("./svg/minus.svg");
    --termeenrichi-background-image-expanded-reversed: url("./svg/minus-reversed.svg");

    --header-background-color: #FFF1C3;
    --header-border-color: #B35F1F;
    --header-color: #000;
    --header-dropdown-background: 99% center no-repeat url("./svg/chevron-bottom.svg");

    --toc-border-color: #FFF1C3;
    --toc-border-active-color: #B35F1F;

    --contenuadd-border-color: #B35F1F;
    --contenuadd-background: #FFF8E3;

    --target-background: #78350F;
    --target-color: #fff;

    --footer-background-color: #FFF1C3;
    --footer-border-color: #B35F1F;
}
