<section id="$additional_id$" class="contenuadd texte $if(source)$$source$$endif$ $if(priority)$$priority$$endif$">
<h3>$title$</h3>

<div class="description">

$body$

</div>

<div class="rdfa" style="display: none">
$if(date)$<span class="date">$date$</span>$endif$
$if(lang)$<span class="lang">$lang$</span>$endif$
$if(keywords)$<span class="keywords">$keywords$</span>$endif$
$if(credits)$<span class="credits">$credits$</span>$endif$
</div>

</section>
