/* From https://github.com/JulietaUla/Montserrat/releases
   Version v7.210
 */

@font-face {
    font-family: "montserrat";
    src: url('./fonts/Montserrat-Regular.woff2') format('woff2'),
         url('./fonts/Montserrat-Regular.woff') format('woff');
    font-weight: normal;
    font-style: normal;
    font-display: swap;
}

@font-face {
    font-family: "montserrat";
    src: url('./fonts/Montserrat-Italic.woff2') format('woff2'),
         url('./fonts/Montserrat-Italic.woff') format('woff');
    font-weight: normal;
    font-style: italic;
    font-display: swap;
}

@font-face {
    font-family: "montserrat";
    src: url('./fonts/Montserrat-Bold.woff2') format('woff2'),
         url('./fonts/Montserrat-Bold.woff') format('woff');
    font-weight: bold;
    font-style: normal;
    font-display: swap;
}

@font-face {
    font-family: "montserrat-medium";
    src: url('./fonts/Montserrat-Medium.woff2') format('woff2'),
         url('./fonts/Montserrat-Medium.woff') format('woff');
    font-weight: normal;
    font-style: normal;
    font-display: swap;
}
