/* Same as h2. */
.references summary {
    font-style: italic;
    font-weight: 400;
    margin-top: 2.1rem;
    margin-bottom: 1.4rem;
    font-size: 2.2rem;
    line-height: 1;
}

#bibliographie-refs {
    max-width: 92%;
}

.references .zotero {
    background: url("./img/zotero_logo.png") left center / 6% no-repeat;
    padding-left: 2.5rem;
}
.references div {
    max-width: 75%;
    font-size: 1.4rem;
    margin-bottom: 1rem;
}
@media (max-width: 1280px) {
    /* Overwrite tufte for responsive text size. */
    .references div {
        font-size: 1.25rem;
        line-height: 1.75;
    }
}
@media (max-width: 760px) {
    /* Overwrite tufte for responsive text size. */
    .references div {
        font-size: 1.1rem;
        line-height: 1.5;
    }
}


