<section id="$additional_id$" class="contenuadd $type$ $if(source)$$source$$endif$ $if(priority)$$priority$$endif$">
<h3>$title$</h3>

<div class="description">

$body$

<p class="credits">Crédits&nbsp;: $credits$ $if(zotero)$$zotero$$endif$</p>
<p class="source">
	<a target="_blank" class="button "href="$link$">Source</a> $if(link-archive)$(<a href="$link-archive$">archive</a>)$endif$
</p>
</div>

<div class="rdfa" style="display: none">
$if(date)$<span class="date">$date$</span>$endif$
$if(lang)$<span class="lang">$lang$</span>$endif$
$if(keywords)$<span class="keywords">$keywords$</span>$endif$
</div>

</section>
