/* Generated with
    https://www.fontsquirrel.com/tools/webfont-generator
    WebOnly + Basic Subsetting
 */

@font-face {
    font-family: "janon";
    src: url('./fonts/jannon10pro.woff2') format('woff2'),
         url('./fonts/jannon10pro.woff') format('woff');
    font-weight: normal;
    font-style: normal;
    font-display: swap;
}

@font-face {
    font-family: "janon";
    src: url('./fonts/jannon10pro-italic.woff2') format('woff2'),
         url('./fonts/jannon10pro-italic.woff') format('woff');
    font-weight: normal;
    font-style: italic;
    font-display: swap;
}

@font-face {
    font-family: "janon";
    src: url('./fonts/jannon10pro-bold.woff2') format('woff2'),
         url('./fonts/jannon10pro-bold.woff') format('woff');
    font-weight: bold;
    font-style: normal;
    font-display: swap;
}
