span[data-idsp] {
    padding-right: 1.5rem;
    background-repeat: no-repeat;
    background-position: center right;
    background-image: var(--termeenrichi-background-image);
    cursor: pointer;
}
span[data-idsp].expanded {
    background-image: var(--termeenrichi-background-image-expanded);
}
span[data-idsp].termeenrichi {
    cursor: inherit;
    padding: 0 .3rem;
}

.termeenrichi {
    position: relative;
    color: var(--balloon-color-font);
    background-color: var(--balloon-color);
    background-repeat: no-repeat;
    background-position: 1% 8%;
    margin: .5rem 0 1rem 0;
    width: 100%;
    left: 0;
    top: 0;
    border-radius: 4px;
}
.termeenrichi .tooltip-title {
    margin-left: 3.5rem;
    padding: 1.2rem 0 1rem 0;
}
.termeenrichi .tooltip-index {
    text-align: center;
    padding: 1rem;
}
    .termeenrichi .tooltip-index a {
        padding: .4rem .7rem;
        border: 2px solid var(--balloon-color-font);
        border-radius: 1rem;
        text-decoration: none;
    }
    .termeenrichi .tooltip-index a:hover {
        color: var(--balloon-color);
        background: var(--balloon-color-font);
    }
.termeenrichi .tooltip-ref {
    text-align: right;
    font-size: 1rem;
    margin: .5rem 1rem;
}
