<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:dc="http://purl.org/dc/terms/"
      xmlns:foaf="http://xmlns.com/foaf/0.1/"
      $if(lang)$ xml:lang="$lang$"$endif$$if(book.dir)$ dir="$book.dir$"$endif$>
<head>
<!--metadonnées dc du chapitre. TODO métadonnées du livre +rdf séparé-->
<link rel="schema.DC" href="http://purl.org/dc/elements/1.1/" />
<link rel="schema.MARCREL" href="http://www.loc.gov/loc.terms/relators/"/>
<link rel="DCTERMS.subject" href="http://rameau.bnf.fr"/>
<link rel="schema.prism" href="http://prismstandard.org/namespaces/basic/2.0/"/>
<link type="application/rdf+xml" id="zotero_rdf" href="$chapter.id$.rdf" title="RDF Bibliontology" /><!--metadonnées en rdf pour zotero-->
<meta charset="utf-8">
<meta name="generator" content="Pressoir $book.pressoir_version$">
<meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=yes">
<meta name="DC.format" content="text/html" />
<meta name="DC.type" content="bookSection" />

<meta name="DC.title" content="$chapter.title_f$" />
<meta name="DC.title.Main" content="$chapter.title_f$" />
$if(chapter.subtitle_f)$
<meta name="DC.title.Subtitle" content="$chapter.subtitle_f$" />
$endif$
<meta name="DC.publisher" class="editeur" content="$book.publisher$" />
<meta name="DC.language" content="$lang$" />
<meta name="DC.date" class="completeDate" content="$book.date$" />
<meta name="DC.date" class="year" content="$book.year$" />
   <meta name="DC.rights" content="$book.rights$" />


$if(chapter.url)$
<meta name="url" content="$chapter.url$" />
<meta name="DC.identifier" content="$chapter.url$" />
$endif$

<meta name="DC.identifier" class="isbn" content="urn:ISBN:$book.isbnnum$" />
<meta name="DC.identifier" class="isbn" content="urn:ISBN:$book.isbnprint$" />
<meta name="DC.identifier" class="isbn" content="urn:ISBN:$book.isbnpdf$" />
<meta name="DC.identifier" class="isbn" content="urn:ISBN:$book.isbnepub$" />


<!--Auteur de l'article -->
$if(chapter.authors)$
$for(chapter.authors)$
<meta name="author" content="$chapter.authors.forname$ $chapter.authors.surname$" />
<meta name="DC.creator" content="$chapter.authors.forname$ $chapter.authors.surname$" />
$endfor$
$endif$

<!--Resumes -->
<meta name="description" xml:lang="fr" lang="fr" content="$chapter.abstract_fr$" />
<meta name="DC.description" xml:lang="fr" lang="fr" content="$chapter.abstract_fr$" />
$if(chapter.abstract_en)$
<meta name="description" xml:lang="en" lang="en" content="$chapter.abstract_en$" />
<meta name="DC.description" xml:lang="en" lang="en" content="$chapter.abstract_en$" />
$endif$

<!--Mots cles auteurs -->
$if(chapter.keyword_fr)$
<meta name="keywords" xml:lang="fr" lang="fr" content="$for(chapter.keyword_fr)$$chapter.keyword_fr$$sep$, $endfor$" />
$endif$

$if(chapter.keyword_en)$
<meta name="keywords" xml:lang="en" lang="en" content="$for(chapter.keyword_en)$$chapter.keyword_en$$sep$, $endfor$" />
$endif$



<!--  traducteur avec specification MARCREL -->
$if(translator)$
$for(translator)$
<meta name="DC.contributor.trl" content="$translator.forname$ $translator.surname$" />
<meta name="MARCREL.trl" content="$translator.forname$ $translator.surname$" />
$endfor$
$endif$




<!-- schema citation : Indexation pour Google Scholar  -->

<meta name="citation_publisher" content="$book.publisher$" />
$for(chapter.authors)$
<meta name="citation_authors" content="$chapter.authors.forname$ $chapter.authors.surname$" />
$endfor$
<meta name="citation_book_title" content="$book.title$" />
<meta name="citation_title" content="$chapter.title_f$" />
$if(chapter.subtitle_f)$
<meta name="citation_subtitle" content="$chapter.subtitle_f$" />
$endif$
<meta name="citation_publication_date" content="$book.date$" />
<meta name="citation_online_date" content="$book.date$" />
<meta name="citation_isbn" content="$book.isbnprint$" />
<meta name="citation_language" content="$lang$" />

<meta name="citation_abstract" xml:lang="fr" lang="fr" content="$chapter.abstract_fr$" />
$if(chapter.abstract_en)$
<meta name="citation_abstract" xml:lang="en" lang="en" content="$chapter.abstract_en$" />
$endif$

$if(chapter.keyword_fr)$
<meta name="citation_keywords" xml:lang="fr" lang="fr" content="$for(chapter.keyword_fr)$$chapter.keyword_fr$$sep$, $endfor$" />
$endif$

$if(chapter.keyword_en)$
<meta name="citation_keywords" xml:lang="en" lang="en" content="$for(chapter.keyword_en)$$chapter.keyword_en$$sep$, $endfor$" />
$endif$


<meta name="citation_pdf_url" content="$book.pdfurl$">



<!--PRISM schema - Publishing Requirements for Industry Standard Metadata
Schema specialise pour les revues et journaux-->
<meta name="prism.url" content="$chapter.url$"/>

<meta name="prism.corporateEntity" content="$book.publisher$"/>

<meta name="prism.publicationDate" content="$book.date$"/>

<meta name="prism.isbn" content="$book.isbnprint$"/>

<meta name="prism.teaser" content="$chapter.abstract_fr$"/>


<!--RDFa pour ajout des metadonnees DC-->
<meta property="dc:format" content="text/html" />
$if(chapter.url)$
<meta property="dc:identifier" content="$chapter.url$" />
$endif$
$if(issnnum)$
<meta property="dc:identifier" content="$book.isbnprint$" />
$endif$
<meta property="dc:title" content="$chapter.title_f$" />
<meta property="dc:title.Main" content="$chapter.title_f$" />
$if(chapter.subtitle_f)$
<meta property="dc:title.Subtitle" content="$chapter.subtitle_f$" />
$endif$
<meta property="dc:publisher" content="$book.publisher$" />
<meta property="dc:language" content="$lang$" />
<meta property="dc:type" content="bookSection" />
<meta property="dcterm:created" content="$book.date$" />
<meta property="dc:rights" content="$book.rights$" />

$for(chapter.authors)$
<meta property="dc:creator" content="$chapter.authors.forname$ $chapter.authors.surname$" />
$endfor$


<meta property="dcterms:abstract" xml:lang="fr" lang="fr" content="$chapter.abstract_fr$" />
$if(chapterabstract_en)$
<meta property="dcterms:abstract" xml:lang="en" lang="en" content="$chapter.abstract_en$" />
$endif$


<!--Fin des metadonnees dans le Head-->

<!-- Social network -->

<meta property="og:type" content="bookSection" />

<meta property="og:url" content="$chapter.url$" />
<meta property="og:title" content="$chapter.title_f$" />
<meta property="og:description" content="$chapter.abstract_fr$ " />
<meta property="og:image" content="$book.coverurl$" />

<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

<title>$pagetitle$</title>

$if(math)$
  $math$
$endif$

<script>
(function(a,b,c){var d=a.history,e=document,f=navigator||{},g=localStorage,
h=encodeURIComponent,i=d.pushState,k=function(){return Math.random().toString(36)},
l=function(){return g.cid||(g.cid=k()),g.cid},m=function(r){var s=[];for(var t in r)
r.hasOwnProperty(t)&&void 0!==r[t]&&s.push(h(t)+"="+h(r[t]));return s.join("&")},
n=function(r,s,t,u,v,w,x){var z="https://www.google-analytics.com/collect",
A=m({v:"1",ds:"web",aip:c.anonymizeIp?1:void 0,tid:b,cid:l(),t:r||"pageview",
sd:c.colorDepth&&screen.colorDepth?screen.colorDepth+"-bits":void 0,dr:e.referrer||
void 0,dt:e.title,dl:e.location.origin+e.location.pathname+e.location.search,ul:c.language?
(f.language||"").toLowerCase():void 0,de:c.characterSet?e.characterSet:void 0,
sr:c.screenSize?(a.screen||{}).width+"x"+(a.screen||{}).height:void 0,vp:c.screenSize&&
a.visualViewport?(a.visualViewport||{}).width+"x"+(a.visualViewport||{}).height:void 0,
ec:s||void 0,ea:t||void 0,el:u||void 0,ev:v||void 0,exd:w||void 0,exf:"undefined"!=typeof x&&
!1==!!x?0:void 0});if(f.sendBeacon)f.sendBeacon(z,A);else{var y=new XMLHttpRequest;
y.open("POST",z,!0),y.send(A)}};d.pushState=function(r){return"function"==typeof d.onpushstate&&
d.onpushstate({state:r}),setTimeout(n,c.delay||10),i.apply(d,arguments)},n(),
a.ma={trackEvent:function o(r,s,t,u){return n("event",r,s,t,u)},
trackException:function q(r,s){return n("exception",null,null,null,null,r,s)}}})
(window,"UA-48507568-1",{anonymizeIp:true,colorDepth:true,characterSet:true,screenSize:true,language:true});
</script>
<link rel="stylesheet" href="static/$meta.css_filename$" />
<meta property="pressoir:indexes" content="$for(meta.indexes)$$it$$sep$,$endfor$">
<meta property="pressoir:glossaire-button-label" content="$meta.glossaire.button.label$">
<meta property="pressoir:glossaire-button-title" content="$meta.glossaire.button.title$">

$for(header-includes)$
  $header-includes$
$endfor$
</head>

<body data-chapitre="$chapter.id$">
$for(include-before)$
  $include-before$
$endfor$

<header class="main">
  <a  href="$if(book.url_publisher)$$book.url_publisher$$else$/$endif$" class="logo" title="Accéder à l’accueil"></a>
  <div class="title">
    <h1><a href="index.html">$book.title$</a></h1>
    <h2><a href="$chapter.url_relative$" title="Naviguer directement entre chapitre">$chapter.title_h$</a></h2>
  </div>
  <nav aria-role="main">
    <ul>
      $for(book.chapters_and_parts)$
        <li>
          $if(it.url_relative)$
            <a href="$it.url_relative$">$it.title$</a>
          $else$
            $it.title$
          $endif$
          $if(it.chapters)$
            <ul>
              $for(it.chapters)$
                <li><a href="$it.url_relative$">$it.title_h$</a></li>
              $endfor$
            </ul>
          $endif$
        </li>
      $endfor$
    </ul>
  </nav>

  <nav aria-role="prev-next">
    <ul>
      <li>
        <a rel="prev" href="$prev.url_relative$" title="$prev.title_f$"></a>
      </li>
      <li>
        <a rel="next" href="$next.url_relative$" title="$next.title_f$"></a>
      </li>
    </ul>
  </nav>

</header>


<div class="toc"></div>

<article>
<header>
$if(book.has_search)$
  $if(chapter.is_not_search)$
    <form action="recherche.html" method="get" class="searchnote">
      <p>
        <input id="input-search" type="search" name="q"
          aria-label="Termes de votre recherche"
          aria-describedby="indexation-infos" required>
        <input type="submit" value="Chercher">
      </p>
    </form>
  $endif$
$endif$
$if(chapter.title)$
<h1 class="title">$chapter.title$</h1>
$endif$
$if(chapter.subtitle)$
<p class="subtitle">$chapter.subtitle$</p>
$endif$
$for(chapter.authors)$
  $if(chapter.authors.display)$
  $else$
    $if(book.collective)$
      <p class="author">
        $if(chapter.authors.iddescription)$
          <a href="$chapter.authors.iddescription$">$chapter.authors.forname$ $chapter.authors.surname$</a>
        $else$
          <u>$chapter.authors.forname$ $chapter.authors.surname$</u>
        $endif$
        $if(chapter.authors.orcidurl)$
          <a href="$chapter.authors.orcidurl$"><img height="20px" width="20px" src="static/svg/logo_orcid.svg"></a>
        $endif$
      </p>
    $endif$
  $endif$
$endfor$
$if(chapter.translators)$
  $for(chapter.translators)$
    <p class="translator">Traduit par
      $if(chapter.translators.iddescription)$
        <a href="$chapter.translators.iddescription$">$chapter.translators.forname$ $chapter.translators.surname$</a>
      $else$
        <u>$chapter.translators.forname$ $chapter.translators.surname$</u>
      $endif$
      $if(chapter.translators.orcidurl)$
        <a href="$chapter.translators.orcidurl$"><img height="20px" width="20px" src="static/svg/logo_orcid.svg"></a>
      $endif$
    </p>
  $endfor$
$endif$
$if(chapter.blockcitation)$
<section><p><label for="mn-demo" class="margin-toggle">&#8853;</label>
<input type="checkbox" id="mn-demo" class="margin-toggle"/>
  $if(chapter.url_traduction)$
    <span class="marginnote url-trad">$chapter.url_traduction$</span>
  $endif$
  <span class="marginnote infochapitre">
    $for(chapter.authors)$
      $chapter.authors.forname$ $chapter.authors.surname$$sep$,
    $endfor$,
    «&nbsp;$chapter.title_f$&nbsp;»,
    $if(chapter.translators)$
      (traduit par
      $for(chapter.translators)$
        $chapter.translators.forname$ $chapter.translators.surname$$sep$,
      $endfor$),
    $endif$
    $if(book.collective)$
      dans
      $if(book.authors)$
        $for(book.authors)$
          $book.authors.forname$ $book.authors.surname$$sep$,
        $endfor$ (dir.),
      $endif$
    $endif$
    <em>$book.title$</em> (édition augmentée), $book.publisher$, $book.place$, $book.year$, ISBN&nbsp;: $book.isbnnum$, $chapter.url$.<br>
    version $book.version$, $book.day$/$book.month$/$book.year$<br/>
    $book.rights$
  </span>
</p></section>
$endif$
</header>
<main>
<section>

  $body$

  $for(chapter.authors)$
    $if(chapter.authors.presentation)$
      <h3 id="biographie-$chapter.authors.surname$">$chapter.authors.forname$ $chapter.authors.surname$</h3>
      <p>$chapter.authors.presentation$</p>
    $endif$
  $endfor$

</section>
</main>
</article>
<footer>
  <nav>
    <ul>
      <li>
        <a href="$prev.url_relative$" title="$prev.title_f$">
          $prev.title_f$
        </a>
      </li>
      <li>$meta.index$ / $meta.nb_of_chapters$</li>
      <li>
        <a href="$next.url_relative$" title="$next.title_f$">
          $next.title_f$
        </a>
      </li>
    </ul>
  </nav>
</footer>

$for(include-after)$
  $include-after$
$endfor$
<script src="static/$meta.js_filename$"></script>
<script src="https://hypothes.is/embed.js" async="async"></script>
<script type="text/javascript">
  document.addEventListener("DOMContentLoaded", () => {
    const markInstance = new Mark(document.querySelector('main'))
    let query = new URLSearchParams(window.location.search).get('q')
    if (!query) return

    // Remove previous marked elements and mark
    // the new keyword inside the context
    markInstance.unmark({
      done: function(){
        markInstance.mark(query)
      }
    })
  })
</script>
</body>
</html>
