/* Box sizing rules */
*,
*::before,
*::after {
  box-sizing: border-box;
}

body {
    width: inherit;
    padding: 0;
    margin: 0;
    max-width: inherit;
    background: var(--body-background);
    color: var(--body-color);
}

article {
    margin-left: 22rem;
    max-width: 1400px;
    padding: 3rem 0rem;
}

article ul {
    max-width: 50%;
}

section > h2 {
    width: 55%;
    line-height: 1.45;
}
section:not(.contenuadd) > h3 {
    width: 55%;
    line-height: 1.4;
}
section > h4 {
    width: 55%;
    line-height: 1.3;
}
section > h5 {
    width: 55%;
    line-height: 1.25;
}

section > h2 em {
    font-style: normal;
}

body,
input,
.numeral,
.sidenote-number:after,
.sidenote:before {
    font-family: var(--font-family);
}

/* CSS extracted from inline styles. */
code {
    white-space: pre;
}
pre {
    font-size: 0.9rem;
    width: 52.5%;
    margin-left: 2.5%;
    overflow-x: auto;
}
table {
    border-top: 2px solid #111;
    border-bottom: 2px solid #111;
    font-size: 1.1rem;
    word-break: break-word;
}
th {
    border-bottom: 1px solid #111;
}


/* Reset tufte */
p {
    line-height: 2.15rem;
}
.sidenote,
.marginnote {
    margin-right: -50%;
    width: 40%;
    padding-top: .5rem;
    padding-bottom: .5rem;
}
.marginnote.infochapitre {
    margin-bottom: 1rem;
}
[role="doc-backlink"] {
    display: none;
}
figure {
    text-align: center;
    margin-top: 2rem;
}
figcaption {
    text-align: center;
    float: none;
    clear: none;
    max-width: 100%;
    position: static;
}
figcaption .sidenote {
    text-align: left;
}
a:link {
    text-decoration-skip-ink: auto;
    text-decoration: underline;
    background: none;
    text-shadow: none;
}
article ul.full-width {
    max-width: 90%;
    padding-left: 0;
}
::target-text,
mark {
    background-color: #FECC63;
    padding: 1px 3px;
    border-radius: 2px;
}
