/* Useful when loading the page with a given anchor. */
article h1::before {
    display: block;
    content: " ";
    height: 10rem;
    margin-top: -10rem;
    visibility: hidden;
}
article h2,
article h3 {
  scroll-margin-top: 10rem;
}
h1, h2,
summary,
.dossier > h3, .video > h3, .pdf > h3 {
    outline: 0;
}

.toc {
    position: fixed;
    top: 11rem;
    left: 2rem;
    max-width: 18rem;
}
.toc ol {
    font-size: 1rem;
}
.toc a {
    text-decoration: none;
}
.toc a:hover {
    text-decoration: underline;
}
.is-active-link::before {
    background-color: var(--toc-border-active-color);
}
