/* Beware: Safari does not handle well relative paths in CSS vars.
   See https://bugs.webkit.org/show_bug.cgi?id=190807 for reference. */
:root {
    --font-family: 'montserrat';
    --body-background: #fff no-repeat right 95% url("./svg/parcours-numeriques.png");
    --body-color: #432c2c;

    --logo-position: no-repeat left center/110%;
    --logo-url: url("./svg/pum-logo-couleur.svg");
    --small-logo-url: url("./svg/pum-logo-couleur.svg");

    --balloon-color: #686868;
    --balloon-color-font: #e9ecef;
    --balloon-font-size: .9rem;

    --termeenrichi-background-image: url("./svg/plus.svg");
    --termeenrichi-background-image-expanded: url("./svg/minus.svg");

    --header-background-color: #eaeaea;
    --header-border-color: #f00;
    --header-color: #000;
    --header-dropdown-background: 99% center no-repeat url("./svg/chevron-bottom.svg");

    --toc-border-color: #b3b3b3;
    --toc-border-active-color: #000;

    --contenuadd-border-color: #b3b3b3;
    --contenuadd-background: #eaeaea;

    --footer-background-color: #eaeaea;
    --footer-border-color: #f00;
}
