footer {
    border-top: 2px solid var(--footer-border-color);
    background: var(--footer-background-color);
    width: 100%;
}

footer nav ul {
    margin: 0;
    padding: 0;
    list-style: none;
    display: flex;
    justify-content: space-between;
    width: 100%;
}
footer nav ul li {
    height: 100%;
    margin: 0;
    padding: .5rem 1rem;
    font-size: 1.5rem;
}
footer nav ul li:first-child a {
    background: url("./svg/chevron-left.svg") center left no-repeat;
    padding-left: 2rem !important;
}
footer nav ul li:last-child a {
    background: url("./svg/chevron-right.svg") center right no-repeat;
    padding-right: 2rem !important;
}
footer nav ul li:not(:first-child):not(:last-child) {
    margin-top: 0; /* Override tufte.css */
    border-left: 2px solid var(--footer-border-color);
    border-right: 2px solid var(--footer-border-color);
    white-space: nowrap;
    height: 4rem;
    padding-top: .8rem;
}
footer nav ul li a:link {
    padding: .1rem;
    text-decoration: none;
}
