.indexnp-entry {
    display: flex;
    margin: 0 0 0.5rem 0;
}

.indexnp-entry .text {
    flex-shrink: 0;
}

.indexnp-entry .dots {
    flex-shrink: 1;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: clip;
}

.indexnp-entry .dots::after {
    font-weight: normal;
    content: ". . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ";
}

.indexnp-entry .number {
    flex-shrink: 0;
    text-align: right;
}
