section.contenuadd p {
    width: 100%;
}

.contenuadd {
    max-width: 55%;
    background-repeat: no-repeat;
    background-color: var(--contenuadd-background);
    background-position: 99% .5rem;
    background-image: url("./svg/additional.svg");
    border-left: 5px solid var(--contenuadd-border-color);
    -webkit-border-radius: 3px;
    border-radius: 3px;
    margin-bottom: 1em;
    padding-top: .1rem;
    padding-bottom: .1rem;
}

.contenuadd .contenuadd {
    background: none;
    background-color: var(--contenuadd-background);
    -webkit-border-radius: 3px;
    border-radius: 3px;
    border: 3px solid lightgrey;
    margin-bottom: 1em;
    padding-top: 0;
}

.contenuadd figure {
    margin: 1.5rem;
    max-width: 100%;
}
.contenuadd figure img {
    border: 1px solid var(--contenuadd-border-color);
    padding: 1px;
}
.contenuadd figcaption {
    font-style: italic;
}

.contenuadd h3 {
    font-size: 1.4em;
    font-style:normal;
    outline: 0;
}

.contenuadd.dossier > div.info {
    display:none;
}
.contenuadd p,
.contenuadd ul {
    font-size: large;
    margin-top: 0;
}

.contenuadd p.source {
    font-size: 1em;
    margin-top: 1.4rem;
    color: var(--header-background-color);
}

.contenuadd.highpriority > * {
    margin: 1.5rem;
}
.contenuadd.highpriority iframe {
    margin: .5rem;
}
.contenuadd.highpriority.image {
    background-image: url("./svg/image.svg");
}
.contenuadd.highpriority.video {
    background-image: url("./svg/video.svg");
}
.contenuadd.highpriority.audio {
    background-image: url("./svg/audio.svg");
}
.contenuadd.highpriority.article {
    background-image: url("./svg/article.svg");
}
.contenuadd.highpriority.lien {
    background-image: url("./svg/lien.svg");
}
.contenuadd.highpriority.pdf {
    background-image: url("./svg/pdf.svg");
}

.contenuadd.lowpriority {
    background-color: var(--contenuadd-background);
    background-position: 99% .5rem;
    background-repeat: no-repeat;
    background-image: url("./svg/expand.svg");
    padding: 0;
}
.contenuadd.lowpriority.expanded {
    background-image: url("./svg/minimize.svg");
    cursor: inherit;
    padding-bottom: 0.1rem;
}
.contenuadd.lowpriority h3 {
    padding: 1.5rem 2.5rem 1.5rem 1.5rem;
    cursor: pointer;
    margin: 0;
}
.contenuadd.lowpriority > *:not(h3):not(iframe) {
    visibility: hidden;
    opacity: 0;
    height: 0;
    transition: visibility 0s, opacity 0.5s linear, height 1s linear;
    padding: 0;
    max-width: 100%;
}
/* Special treatment for iframes because they have native height defined
within the HTML attributes and we cannot retrieve that information once
we set it to 0. */
.contenuadd.lowpriority > iframe {
    display: none;
}
.contenuadd.lowpriority.expanded h3 {
    padding-bottom: 1.5rem;
}
.contenuadd.lowpriority.expanded > *:not(h3):not(iframe) {
    display: block;
    visibility: visible;
    height: inherit;
    opacity: 1;
}
.contenuadd.lowpriority.expanded > iframe {
    display: block;
}

.contenuadd.lowpriority.expanded .description,
.contenuadd.highpriority .description {
    background: white;
    padding: 0 1rem 1rem 1rem;
    margin: 0 .5rem .5rem;
    -webkit-border-radius: 3px;
    border-radius: 3px;
}
.contenuadd.lowpriority.expanded .credits {
    text-align: right;
    font-style: italic;
}
.contenuadd.lowpriority.expanded .source,
.contenuadd.highpriority .source {
    text-align: center;
    display: inline-block;
}
.contenuadd.lowpriority.expanded .source a.button,
.contenuadd.highpriority .source a.button {
    font-size: 1.2rem;
    background: no-repeat var(--contenuadd-border-color) 80% 40%/20% url("./svg/source.svg");
    color: var(--contenuadd-background);
    padding: .75rem 4rem .75rem 1.5rem;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    text-shadow: none;
}
.contenuadd.lowpriority.expanded .info,
.contenuadd.highpriority .info {
    margin: 0 .5rem;
}
.contenuadd.lowpriority.expanded .info p,
.contenuadd.highpriority .info p {
    text-align: right;
    font-style: italic;
    font-size: .9rem;
    color: #666666;
    margin: 0;
}

.contenuadd.lowpriority.expanded .iframe-video,
.iframe-video {
    position: relative;
    width: 90%;
    height: 0;
    padding-bottom: 56.25%;
    margin: 0 auto;
}
.contenuadd.lowpriority.expanded .iframe-audio,
.iframe-audio {
    position: relative;
    width: 90%;
    height: 0;
    padding-bottom: 180px;
    margin: 0 auto;
}
.contenuadd.lowpriority.expanded .iframe-map,
.iframe-map {
    position: relative;
    width: 90%;
    height: 0;
    padding-bottom: 90%;
    margin: 0 auto;
}
.iframe-video iframe,
.iframe-audio iframe,
.iframe-map iframe {
    position: absolute;
    width: 100%;
    height: 100%;
    left: 0;
    top: 0;
    overflow:hidden;
    padding: 1rem;
}
.contenuadd.lowpriority.expanded .description:has(> pre),
.contenuadd.highpriority .description:has(> pre) {
    padding: 0;
}
.contenuadd pre {
    width: auto;
}
.contenuadd pre > code {
    width: 96%;
}
