/* The place to define a new theme/identity. */
h1, h2, h3, h4, h5, h6 {
    font-family: var(--font-family-headers);
}

header.main a.logo {
  width: 322px;
}

header.main {
    border-bottom-width: 2px;
}

header.main h1 {
    font-variant: small-caps;
}

header.main h2 a {
    border-color: var(--body-color);
}

h1.title {
    margin-top: 7rem;
    font-size: 4rem;
    max-width: 60rem;
    line-height: 1.15;
    margin-bottom: 3rem;
    color: black;
    font-variant: small-caps;
}
h1.title::after {
    display: block;
    content: " ";
    height: 2px;
    width: 50%;
    background: red;
    margin-top: 2rem;
    margin-left: 3rem;
}

blockquote::after,
.introchapitre::after,
.sidenote::after,
.marginnote::after {
    display: block;
    content: " ";
    height: 2px;
    width: 35%;
    background: red;
    margin-top: 1rem;
    margin-bottom: 2rem;
    margin-left: 8rem;
}

blockquote {
    background: no-repeat top left/3rem url("./svg/quote.svg");
    padding-top: 1rem;
    padding-left: 3.5rem;
    margin: 4rem 0 4rem -1.5rem;
}
blockquote::after,
.introchapitre::after {
    width: 13%;
    margin-left: 30rem;
}

blockquote p {
    margin-top: 0;
    width: 54%;
}

@media (max-width: 760px) {
    blockquote::after,
    .introchapitre::after {
        width: 13%;
        margin-left: 10rem;
    }

    blockquote p,
    blockquote ul,
    blockquote ol {
        width: 80%;
        font-size: medium;
        line-height: 1.5;
    }
}

img {
    border-bottom: 2px solid red;
}
blockquote img {
    border-bottom: none;
    margin: 2rem;
}

.introchapitre,
.concluchapitre {
    font-family: 'averialibre-bold-custom';
    width: 55%;
}
.introchapitre {
    margin-bottom: 5rem;
}

.introchapitre p::first-letter,
.concluchapitre p::first-letter {
  font-size: 5rem;
  padding-left: .5rem;
  padding-right: .5rem;
  float: left;
  color: red;
}

.epigraphe {
    width: 50%;
    text-align: right;
    margin: 1rem 0 5rem 7rem;
}
.epigraphe p {
    margin-right: 2rem;
    font-size: 1.1rem;
    color: black;
}
.epigraphe p .citation {
    display: block;
}

.contenuadd,
.contenuadd a,
.contenuadd p.source {
    color: var(--body-color);
}
.contenuadd.lowpriority.expanded .source a.button,
.contenuadd.highpriority .source a.button {
    background-color: var(--body-color);
}

footer {
    border-top: 2px solid #b3b3b3;
    background: white;
    width: 100%;
}

footer nav ul {
    font-variant: small-caps;
}

footer nav ul li:not(:first-child):not(:last-child) {
    border-left: none;
    border-right: none;
}
footer nav ul li:not(:first-child):not(:last-child)::before {
    display: inline-block;
    content: " ";
    height: 40%;
    width: 2px;
    background: var(--footer-border-color);
    margin-right: 1rem;
}
footer nav ul li:not(:first-child):not(:last-child)::after {
    display: inline-block;
    content: " ";
    height: 40%;
    width: 2px;
    background: var(--footer-border-color);
    margin-left: 1rem;
}

@media (max-width: 1025px) {
    header.main a.logo {
        background-image: url("./svg/pum-logo-couleur.svg");
    }
}

table tbody tr.odd {
    background: var(--contenuadd-background);
}
table tbody td {
    padding: 0.2rem;
    min-width: 65px;
}

.grand-tableau table {
    font-size: 0.75em;
}

.contenuadd.lowpriority.expanded .description:has(> pre),
.contenuadd.highpriority .description:has(> pre) {
    padding: 0;
}
.contenuadd pre {
    width: auto;
}

pre > code {
    font-size: 1rem;
    white-space: pre-wrap;
    width: auto;
}
.contenuadd pre > code {
    width: 98%;
}

article ul {
    max-width: none;
}

    code {
      font-family: Menlo, Monaco, 'Lucida Console', Consolas, monospace;
      font-size: 85%;
      margin: 0;
    }
    pre {
      margin: 1em 0;
      overflow: auto;
    }
    pre code {
      padding: 0;
      overflow: visible;
      overflow-wrap: normal;
    }
    .sourceCode {
     width:55%;
     background-color: transparent;
     overflow: visible;
    }
    .sourceCode .sourceCode,
    li .sourceCode {
        width: 98%;
    }
code{white-space: pre-wrap;}
    span.smallcaps{font-variant: small-caps;}
    span.underline{text-decoration: underline;}
    div.column{display: inline-block; vertical-align: top; width: 50%;}
    div.hanging-indent{margin-left: 1.5em; text-indent: -1.5em;}
    ul.task-list{list-style: none;}
    pre > code.sourceCode { white-space: pre; position: relative; }
    pre > code.sourceCode > span { display: inline-block; line-height: 1.25; width: 98%; }
    pre > code.sourceCode > span.highlight { background: #00ffcf3b; }
    pre > code.sourceCode > span:empty { height: 1.2em; }
    .sourceCode { overflow: visible; }
    code.sourceCode > span { color: inherit; text-decoration: inherit; }
    div.sourceCode { margin: 1em 0; }
    pre.sourceCode { margin: 0; }
    @media screen {
    div.sourceCode { overflow: auto; }
    }
    @media print {
    pre > code.sourceCode { white-space: pre-wrap; }
    pre > code.sourceCode > span { text-indent: -5em; padding-left: 5em; }
    }
    pre.numberSource code
      { counter-reset: source-line 0; }
    pre.numberSource code > span
      { position: relative; left: -4em; counter-increment: source-line; }
    pre.numberSource code > span > a:first-child::before
      { content: counter(source-line);
        position: relative; left: -1em; text-align: right; vertical-align: baseline;
        border: none; display: inline-block;
        -webkit-touch-callout: none; -webkit-user-select: none;
        -khtml-user-select: none; -moz-user-select: none;
        -ms-user-select: none; user-select: none;
        padding: 0 4px; width: 4em;
        color: #aaaaaa;
      }
    pre.numberSource { margin-left: 3em; border-left: 1px solid #aaaaaa;  padding-left: 4px; }
    div.sourceCode
      {  background-color: #f8f8f8; }
    @media screen {
    pre > code.sourceCode > span > a:first-child::before { text-decoration: underline; }
    }
    code span.al { color: #ef2929; } /* Alert */
    code span.an { color: #8f5902; font-weight: bold; font-style: italic; } /* Annotation */
    code span.at { color: #c4a000; } /* Attribute */
    code span.bn { color: #0000cf; } /* BaseN */
    code span.cf { color: #204a87; font-weight: bold; } /* ControlFlow */
    code span.ch { color: #4e9a06; } /* Char */
    code span.cn { color: #000000; } /* Constant */
    code span.co { color: #8f5902; font-style: italic; } /* Comment */
    code span.cv { color: #8f5902; font-weight: bold; font-style: italic; } /* CommentVar */
    code span.do { color: #8f5902; font-weight: bold; font-style: italic; } /* Documentation */
    code span.dt { color: #204a87; } /* DataType */
    code span.dv { color: #0000cf; } /* DecVal */
    code span.er { color: #a40000; font-weight: bold; } /* Error */
    code span.ex { } /* Extension */
    code span.fl { color: #0000cf; } /* Float */
    code span.fu { color: #204a87; } /* Function */
    code span.im { } /* Import */
    code span.in { color: #8f5902; font-weight: bold; font-style: italic; } /* Information */
    code span.kw { color: #204a87; font-weight: bold; } /* Keyword */
    code span.op { color: #ce5c00; font-weight: bold; } /* Operator */
    code span.ot { color: #8f5902; } /* Other */
    code span.pp { color: #8f5902; font-style: italic; } /* Preprocessor */
    code span.sc { color: #000000; } /* SpecialChar */
    code span.ss { color: #4e9a06; } /* SpecialString */
    code span.st { color: #4e9a06; } /* String */
    code span.va { color: #000000; } /* Variable */
    code span.vs { color: #4e9a06; } /* VerbatimString */
    code span.wa { color: #8f5902; font-weight: bold; font-style: italic; } /* Warning */
    .display.math{display: block; text-align: center; margin: 0.5rem auto;}
