@font-face {
    font-family: 'averiaseriflibre-light-custom';
    src: url('./fonts/averiaseriflibre-light.woff2') format('woff2');
    font-weight: normal;
    font-style: normal;
    font-display: swap;
}
@font-face {
    font-family: 'averialibre-bold-custom';
    src: url('./fonts/averialibre-bold.woff2') format('woff2');
    font-weight: bold;
    font-style: normal;
    font-display: swap;
}
@font-face {
    font-family: 'averialibre-bold-custom';
    src: url('./fonts/averialibre-bolditalic.woff2') format('woff2');
    font-weight: bold;
    font-style: italic;
    font-display: swap;
}
